@@ -1,7 +1,10 @@
 import sys
 import os
 import time
-
+import uuid
+from fabric.api import env, run, cd, get, hide, settings, remote_tunnel, show
+from fabric.tasks import execute
+from fabric.decorators import with_settings
 
 JOB_SCHEDULERS = ('SGE','SLURM','LSF','PBS','TORQUE','MAUI','LOADLEVELER')
 
@@ -22,8 +25,31 @@ def detect_scheduling_sys():
     return None
 
 def queues():
-    return scheduler.queues()
+    if scheduler != None:
+        return scheduler.queues()
+    else:
+        return []
 
+def remote_sites():
+    if job_db != None:
+        return job_db.remote_site_db
+    else:
+        return []
+    
+@with_settings(warn_only=True)
+def remote_cmd():
+    output_file =  '~/.mycluster/'+str(uuid.uuid4())
+    with hide('output','running','warnings'), settings(warn_only=True): 
+        run('mycluster -p >'+output_file,pty=False)
+        import StringIO
+        contents = StringIO.StringIO()
+        get(output_file, contents)
+        # operate on 'contents' like a file object here, e.g. 'print
+        return contents.getvalue()
+    
+def remote_job_list(site):
+    env.use_ssh_config = True
+    return execute(remote_cmd,hosts=[site])
 
 def print_timedelta(td):
     if (td.days > 0):
@@ -130,7 +156,12 @@ def printjobs(num_lines):
                                                              )
                   )
             
-            
+    remotes = remote_sites()
+    for i,j in enumerate(remotes):
+        print 'Remote Site: '+remotes[j].name
+        remote_list = remote_job_list(remotes[j].user+'@'+remotes[j].name)
+        for r in remote_list:
+            print remote_list[r]
 
 def print_queue_info():
     print('{0:25} | {1:^15} | {2:^15} | {3:^15} | {4:^15} | {5:^15}'.format('Queue Name','Node Max Task','Node Max Thread','Node Max Memory','Max Task','Available Task'))
@@ -161,35 +192,44 @@ def create_submit(queue_id,script_name=None,**kwargs):
     return script
 
 def submit(script_name):
-    job_id = scheduler.submit(script_name)
-    if job_db != None:
-        from mycluster.persist import Job
-        job = Job(job_id,time.time())
-        with open(script_name,'r') as f:
-            for line in f:
-                if line.split('=')[0] == 'export NUM_TASKS':
-                    job.num_tasks = line.split('=')[1].strip()
-                if line.split('=')[0] == 'export TASKS_PER_NODE':
-                    job.tasks_per_node = line.split('=')[1].strip()
-                if line.split('=')[0] == 'export THREADS_PER_TASK':
-                    job.threads_per_task = line.split('=')[1].strip()
-                if line.split('=')[0] == 'export NUM_NODES':
-                    job.num_nodes = line.split('=')[1].strip()
-                if line.split('=')[0] == 'export MYCLUSTER_QUEUE':
-                    job.queue = line.split('=')[1].strip()
-                if line.split('=')[0] == 'export MYCLUSTER_JOB_NAME':
-                    job.job_name = line.split('=')[1].strip()
-        
-        job.script_name = script_name
-        job.job_dir = os.path.dirname(os.path.abspath(script_name))
-        job_db.add(job)
-        job_db.add_queue(job.queue,scheduler.name())
+    
+    job_id = -1
+    import os.path
+    if os.path.isfile(script_name):    
+        job_id = scheduler.submit(script_name)
+        if job_db != None:
+            from mycluster.persist import Job
+            job = Job(job_id,time.time())
+            with open(script_name,'r') as f:
+                for line in f:
+                    if line.split('=')[0] == 'export NUM_TASKS':
+                        job.num_tasks = line.split('=')[1].strip()
+                    if line.split('=')[0] == 'export TASKS_PER_NODE':
+                        job.tasks_per_node = line.split('=')[1].strip()
+                    if line.split('=')[0] == 'export THREADS_PER_TASK':
+                        job.threads_per_task = line.split('=')[1].strip()
+                    if line.split('=')[0] == 'export NUM_NODES':
+                        job.num_nodes = line.split('=')[1].strip()
+                    if line.split('=')[0] == 'export MYCLUSTER_QUEUE':
+                        job.queue = line.split('=')[1].strip()
+                    if line.split('=')[0] == 'export MYCLUSTER_JOB_NAME':
+                        job.job_name = line.split('=')[1].strip()
+            
+            job.script_name = script_name
+            job.job_dir = os.path.dirname(os.path.abspath(script_name))
+            job_db.add(job)
+            job_db.add_queue(job.queue,scheduler.name())
+    else:
+        print('Error file: {0} does not exist.'.format(script_name))
         
     return job_id
 
 def delete(job_id):
     scheduler.delete(job_id)
 
+def add_remote(remote_site):
+    if job_db != None:
+        job_db.add_remote(remote_site)
 
 def export(job_id):
     pass
@@ -227,21 +267,24 @@ def create_db():
     try:
         from mycluster.persist import JobDB
         job_db = JobDB()    
-    except:
-        pass
+    except Exception as e:
+        print 'Database failed to initialise. Error Message: ' + str(e)
+        
+    return job_db
         
 def update_db():
-    status_dict = scheduler.status()
-    jobs = job_list()
-    for j in jobs:
-        if jobs[j].status != 'completed':
-            if j in status_dict:
-                state = status_dict[j]
-                if state == 'r':
-                    jobs[j].update_status('running')
-            else:
-                jobs[j].update_status('completed')
-                jobs[j].update_stats(scheduler.job_stats(j))
+    if scheduler != None:
+        status_dict = scheduler.status()
+        jobs = job_list()
+        for j in jobs:
+            if jobs[j].status != 'completed':
+                if j in status_dict:
+                    state = status_dict[j]
+                    if state == 'r':
+                        jobs[j].update_status('running')
+                else:
+                    jobs[j].update_status('completed')
+                    jobs[j].update_stats(scheduler.job_stats(j))
                 
 def sysscribe_update(job_id):
     if job_db != None:
@@ -269,13 +312,11 @@ def appdata_update(job_id,appdata):
 def init():
     global scheduler
     scheduler = detect_scheduling_sys()
-    if scheduler != None:
-        create_directory()
-        create_db()
+    create_directory()
+    if create_db() != None:
         update_db()
-    else:
-        print('No job schedulers found - exiting')
-        sys.exit()
+    if not scheduler:
+        print('No local job schedulers found')
     
     
 """
